@@ -51,6 +51,9 @@ class WLoadingIndicator;
 class WLogEntry;
 class WResource;
 class WText;
+#ifndef WT_TARGET_JAVA
+class WWebSocketResource;
+#endif // WT_TARGET_JAVA
 
 class WebSession;
 class RootContainer;
@@ -606,9 +609,10 @@ public:
    * By passing an empty \p locale, the default locale is
    * chosen.
    *
-   * When the locale is changed, refresh() is called, which will
-   * resolve the strings of the current user-interface in the new
-   * locale.
+   * By default, when the locale is changed, refresh() is called, 
+   * which will resolve the strings of the current user-interface
+   * in the new locale. This can be changed by having the 
+   * \p doRefresh parameter set to \p false.
    *
    * At construction, the locale is copied from the environment
    * (WEnvironment::locale()), and this is the locale that was
@@ -617,7 +621,7 @@ public:
    *
    * \sa localizedStrings(), WString::tr()
    */
-  void setLocale(const WLocale& locale);
+  void setLocale(const WLocale& locale, bool doRefresh = true);
 
   /*! \brief Returns the current locale.
    *
@@ -2412,6 +2416,9 @@ private:
 
   SignalMap exposedSignals_;   // signals that may be accessed
   ResourceMap exposedResources_; // resources that may be accessed
+#ifndef WT_TARGET_JAVA
+  std::map<WResource*, WWebSocketResource*> exposedWebSocketResources_; // link between exposed resource and their websocket "interface"
+#endif // WT_TARGET_JAVA
   ObjectMap encodedObjects_;   // objects encoded for internal purposes
                                  // like 'virtual pointers' (see D&D)
   std::set<std::string> justRemovedSignals_;
@@ -2461,6 +2468,16 @@ private:
   WResource *decodeExposedResource(const std::string& resourceMapKey,
                                    unsigned long rand) const;
 
+#ifndef WT_TARGET_JAVA
+  // Manipulation of the link between websocket resources and resources
+
+  // Adds a (private) WWebSocketResource to the application.
+  // It functions similarly to simply adding a normal WResource
+  void addWebSocketResource(WWebSocketResource* webSocketResource);
+  void removeWebSocketResource(WWebSocketResource* webSocketResource);
+  WWebSocketResource* findMatchingWebSocketResource(WResource* resource) const;
+#endif // WT_TARGET_JAVA
+
   /*
    * Methods for application state handling
    */
@@ -2530,6 +2547,9 @@ private:
   friend class WTimer;
   friend class WViewWidget;
   friend class WWidget;
+#ifndef WT_TARGET_JAVA
+  friend class WWebSocketResource;
+#endif // WT_TARGET_JAVA
   friend class WWebWidget;
 };
 
